==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/CalendarFormatOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CalendarFormatOptionsDescription } from "./CalendarFormatOptionsDescription";
/**
 * @hidden
 */
export let CalendarFormatOptionsDescriptionMetadata = /*@__PURE__*/ (() => {
    class CalendarFormatOptionsDescriptionMetadata extends Base {
        static b(a) {
            if (CalendarFormatOptionsDescriptionMetadata.a == null) {
                CalendarFormatOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CalendarFormatOptionsDescriptionMetadata.c(CalendarFormatOptionsDescriptionMetadata.a);
            }
            if (a.j(CalendarFormatOptionsDescriptionMetadata.a)) {
                return;
            }
            a.y(CalendarFormatOptionsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Weekday", "String");
            a.item("Month", "String");
        }
        static d(a) {
            CalendarFormatOptionsDescriptionMetadata.b(a);
            a.aa("CalendarFormatOptions", () => new CalendarFormatOptionsDescription());
            a.z("CalendarFormatOptions", CalendarFormatOptionsDescriptionMetadata.a);
        }
    }
    CalendarFormatOptionsDescriptionMetadata.$t = /*@__PURE__*/ markType(CalendarFormatOptionsDescriptionMetadata, 'CalendarFormatOptionsDescriptionMetadata');
    CalendarFormatOptionsDescriptionMetadata.a = null;
    return CalendarFormatOptionsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/CalendarFormatOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CalendarFormatOptionsDescription } from "./CalendarFormatOptionsDescription";
/**
 * @hidden
 */
export let CalendarFormatOptionsDescriptionMetadata = /*@__PURE__*/ (() => {
    class CalendarFormatOptionsDescriptionMetadata extends Base {
        static b(a) {
            if (CalendarFormatOptionsDescriptionMetadata.a == null) {
                CalendarFormatOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CalendarFormatOptionsDescriptionMetadata.c(CalendarFormatOptionsDescriptionMetadata.a);
            }
            if (a.k(CalendarFormatOptionsDescriptionMetadata.a)) {
                return;
            }
            a.aa(CalendarFormatOptionsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Weekday", "String");
            a.item("Month", "String");
        }
        static d(a) {
            CalendarFormatOptionsDescriptionMetadata.b(a);
            a.ac("CalendarFormatOptions", () => new CalendarFormatOptionsDescription());
            a.ab("CalendarFormatOptions", CalendarFormatOptionsDescriptionMetadata.a);
        }
    }
    CalendarFormatOptionsDescriptionMetadata.$t = /*@__PURE__*/ markType(CalendarFormatOptionsDescriptionMetadata, 'CalendarFormatOptionsDescriptionMetadata');
    CalendarFormatOptionsDescriptionMetadata.a = null;
    return CalendarFormatOptionsDescriptionMetadata;
})();
